==> veriloggen-1.2.3-1.tar.gz: veriloggen-1.2.3/tests/extension/thread_/fixed_const/test_thread_fixed_const.py <==
from __future__ import absolute_import
from __future__ import print_function
import veriloggen
import thread_fixed_const

expected_verilog = """
module test;

  reg CLK;
  reg RST;

  blinkled
  uut
  (
    .CLK(CLK),
    .RST(RST)
  );


  initial begin
    $dumpfile("uut.vcd");
    $dumpvars(0, uut);
  end


  initial begin
    CLK = 0;
    forever begin
      #5 CLK = !CLK;
    end
  end


  initial begin
    RST = 0;
    #100;
    RST = 1;
    #100;
    RST = 0;
    #10000;
    $finish;
  end


endmodule



module blinkled
(
  input CLK,
  input RST
);

  reg [8-1:0] LED;
  reg signed [8-1:0] count;
  reg [32-1:0] th_blink;
  localparam th_blink_init = 0;
  reg signed [32-1:0] _th_blink_times_0;
  reg signed [32-1:0] _th_blink_next_val_1;
  reg signed [32-1:0] _th_blink_i_2;

  always @(posedge CLK) begin
    if(RST) begin
      count <= 0;
    end else begin
      count <= count + 'sd8;
    end
  end

  localparam th_blink_1 = 1;
  localparam th_blink_2 = 2;
  localparam th_blink_3 = 3;
  localparam th_blink_4 = 4;
  localparam th_blink_5 = 5;
  localparam th_blink_6 = 6;
  localparam th_blink_7 = 7;
  localparam th_blink_8 = 8;
  localparam th_blink_9 = 9;

  always @(posedge CLK) begin
    if(RST) begin
      th_blink <= th_blink_init;
      _th_blink_times_0 <= 0;
      LED <= 0;
      _th_blink_i_2 <= 0;
    end else begin
      case(th_blink)
        th_blink_init: begin
          _th_blink_times_0 <= 10;
          th_blink <= th_blink_1;
        end
        th_blink_1: begin
          LED <= 0;
          th_blink <= th_blink_2;
        end
        th_blink_2: begin
          _th_blink_next_val_1 <= 0;
          th_blink <= th_blink_3;
        end
        th_blink_3: begin
          _th_blink_i_2 <= 0;
          th_blink <= th_blink_4;
        end
        th_blink_4: begin
          if(_th_blink_i_2 < _th_blink_times_0) begin
            th_blink <= th_blink_5;
          end else begin
            th_blink <= th_blink_9;
          end
        end
        th_blink_5: begin
          _th_blink_next_val_1 <= _th_blink_next_val_1 + 256;
          th_blink <= th_blink_6;
        end
        th_blink_6: begin
          LED <= _th_blink_next_val_1 >> 8;
          th_blink <= th_blink_7;
        end
        th_blink_7: begin
          $display("led =  %d", LED);
          th_blink <= th_blink_8;
        end
        th_blink_8: begin
          _th_blink_i_2 <= _th_blink_i_2 + 1;
          th_blink <= th_blink_4;
        end
      endcase
    end
  end


endmodule
"""


def test():
    veriloggen.reset()
    test_module = thread_fixed_const.mkTest()
    code = test_module.to_verilog()

    from pyverilog.vparser.parser import VerilogParser
    from pyverilog.ast_code_generator.codegen import ASTCodeGenerator
    parser = VerilogParser()
    expected_ast = parser.parse(expected_verilog)
    codegen = ASTCodeGenerator()
    expected_code = codegen.visit(expected_ast)

    assert(expected_code == code)

==> veriloggen-1.4.3.tar.gz: veriloggen-1.4.3/tests/extension/thread_/fixed_const/test_thread_fixed_const.py <==
from __future__ import absolute_import
from __future__ import print_function
import veriloggen
import thread_fixed_const

expected_verilog = """
module test;

  reg CLK;
  reg RST;

  blinkled
  uut
  (
    .CLK(CLK),
    .RST(RST)
  );


  initial begin
    $dumpfile("uut.vcd");
    $dumpvars(0, uut);
  end


  initial begin
    CLK = 0;
    forever begin
      #5 CLK = !CLK;
    end
  end


  initial begin
    RST = 0;
    #100;
    RST = 1;
    #100;
    RST = 0;
    #10000;
    $finish;
  end


endmodule



module blinkled
(
  input CLK,
  input RST
);

  reg [8-1:0] LED;
  reg signed [8-1:0] count;
  reg [32-1:0] th_blink;
  localparam th_blink_init = 0;
  reg signed [32-1:0] _th_blink_times_0;
  reg signed [32-1:0] _th_blink_next_val_1;
  reg signed [32-1:0] _th_blink_i_2;

  always @(posedge CLK) begin
    if(RST) begin
      count <= 0;
    end else begin
      count <= count + 'sd8;
    end
  end

  localparam th_blink_1 = 1;
  localparam th_blink_2 = 2;
  localparam th_blink_3 = 3;
  localparam th_blink_4 = 4;
  localparam th_blink_5 = 5;
  localparam th_blink_6 = 6;
  localparam th_blink_7 = 7;
  localparam th_blink_8 = 8;
  localparam th_blink_9 = 9;

  always @(posedge CLK) begin
    if(RST) begin
      th_blink <= th_blink_init;
      _th_blink_times_0 <= 0;
      LED <= 0;
      _th_blink_i_2 <= 0;
    end else begin
      case(th_blink)
        th_blink_init: begin
          _th_blink_times_0 <= 10;
          th_blink <= th_blink_1;
        end
        th_blink_1: begin
          LED <= 0;
          th_blink <= th_blink_2;
        end
        th_blink_2: begin
          _th_blink_next_val_1 <= 'sd0;
          th_blink <= th_blink_3;
        end
        th_blink_3: begin
          _th_blink_i_2 <= 0;
          th_blink <= th_blink_4;
        end
        th_blink_4: begin
          if(_th_blink_i_2 < _th_blink_times_0) begin
            th_blink <= th_blink_5;
          end else begin
            th_blink <= th_blink_9;
          end
        end
        th_blink_5: begin
          _th_blink_next_val_1 <= _th_blink_next_val_1 + 256;
          th_blink <= th_blink_6;
        end
        th_blink_6: begin
          LED <= _th_blink_next_val_1 >>> 8;
          th_blink <= th_blink_7;
        end
        th_blink_7: begin
          $display("led =  %d", LED);
          th_blink <= th_blink_8;
        end
        th_blink_8: begin
          _th_blink_i_2 <= _th_blink_i_2 + 1;
          th_blink <= th_blink_4;
        end
      endcase
    end
  end


endmodule
"""


def test():
    veriloggen.reset()
    test_module = thread_fixed_const.mkTest()
    code = test_module.to_verilog()

    from pyverilog.vparser.parser import VerilogParser
    from pyverilog.ast_code_generator.codegen import ASTCodeGenerator
    parser = VerilogParser()
    expected_ast = parser.parse(expected_verilog)
    codegen = ASTCodeGenerator()
    expected_code = codegen.visit(expected_ast)

    assert(expected_code == code)
